<?php declare(strict_types=1);


namespace Pinpoint\DropShipping\Controller\Adminhtml\Dropship;


use Magento\Backend\App\Action;
use Magento\Sales\Model\Order\ItemRepository;
use Pinpoint\DropShipping\Model\DropShipItemRepository;

class Delete extends Action
{

    const ADMIN_RESOURCE = 'Pinpoint_DropShipping::top_level';
    protected $_coreRegistry;
    /**
     * @var DropShipItemRepository
     */
    private $repository;
    /**
     * @var ItemRepository
     */
    private $itemRepository;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Registry $coreRegistry
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        DropShipItemRepository $repository,
        ItemRepository $itemRepository,
        \Magento\Framework\Registry $coreRegistry
    ) {
        $this->_coreRegistry = $coreRegistry;
        $this->itemRepository = $itemRepository;
        $this->repository = $repository;
        parent::__construct($context);
    }
    /**
     * Delete action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('dropshipitem_id');
        $orderId = $this->getRequest()->getParam('order_id');
        if ($id) {
            try {
                // init model and delete
                $model = $this->repository->getById($id);

                $orderItem = $this->itemRepository->get($model->getItemId());
                $orderItem->setSupplierName('')
                    ->setMethod(null)
                    ->save();

                $model->delete();
                // display success message
                $this->messageManager->addSuccessMessage(__('You deleted the dropshipped item.'));
                // go to grid
                return $resultRedirect->setPath('sales/order/view',['order_id' => $orderId]);
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('sales/order/view',['order_id' => $orderId]);
            }
        }
        // display error message
        $this->messageManager->addErrorMessage(__('We can\'t find a dropshipped item to delete.'));
        // go to grid
        return $resultRedirect->setPath('sales/order/view',['order_id' => $orderId]);
    }
}

