<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * @category    Pinpoint
 * @copyright   Copyright (c) 2020 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Daniel Cuevas <daniel@pinpointdesigns.co.uk>
 */

namespace Pinpoint\DropShipping\Model\Export\Data\Shared;

use Pinpoint\DropShipping\Model\DropShipItemRepository;
use Pinpoint\DropShipping\Model\ResourceModel\DropShipItem\CollectionFactory as DropShipItemCollectionFactory;
use Pinpoint\DropShipping\Model\SupplierRepository;

/**
 * Class Supplier
 */
class DropshipData extends \Xtento\OrderExport\Model\Export\Data\AbstractData
{
    protected $supplierRepository;
    private $dropshipItemRepository;

    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \Xtento\XtCore\Helper\Date $dateHelper,
        \Xtento\XtCore\Helper\Utils $utilsHelper,
        SupplierRepository $supplierRepository,
        DropShipItemRepository $dropShipItemRepository,
        DropShipItemCollectionFactory $dropShipItemCollectionFactory,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
        array $data = [])
    {
        parent::__construct($context, $registry, $dateHelper, $utilsHelper, $resource, $resourceCollection, $data);
        $this->supplierRepository = $supplierRepository;
        $this->dropshipItemRepository = $dropShipItemRepository;
        $this->dropshipCollectionFactory = $dropShipItemCollectionFactory;
    }

    public function getConfiguration()
    {
        return [
            'name' => 'dropship_data',
            'category' => 'Shared',
            'description' => 'Export fields from the respective *supplier* table and dropship data.',
            'enabled' => true,
            'apply_to' => [\Xtento\OrderExport\Model\Export::ENTITY_ORDER],
        ];
    }

    public function getExportData($entityType, $collectionItem)
    {
        $returnArray = [];
        $this->writeArray = & $returnArray;

        $profile = $this->_registry->registry('orderexport_profile');
        $orderId = $collectionItem->getOrder()->getId();

        if ($profile->getSupplierId()) {
            $supplier = $this->supplierRepository->get($profile->getSupplierId());
            $dropshipTimestamp = $this->dropshipItemRepository->getDropshipDate($profile->getSupplierId(), $orderId, $supplier->getMethod());

            if ($dropshipTimestamp) {
                $this->writeValue('dropship_date', date('d/m/Y', strtotime($dropshipTimestamp)));
            }

            $this->writeArray = & $returnArray['supplier'];

            foreach ($supplier->getData() as $key => $value) {
                $this->writeValue($key, $value);
            }

            if ($dropshipTimestamp) {
                $this->writeArray = &$returnArray['dropship_items'];

                $dropshipItems = $this->dropshipCollectionFactory->create()
                    ->addFieldToFilter('supplier_id', $profile->getSupplierId())
                    ->addFieldToFilter('order_id', $orderId)
                    ->addFieldToFilter('method', $supplier->getMethod());

                foreach ($dropshipItems as $dropshipItem) {
                    $this->writeArray = &$returnArray['dropship_items'][];

                    foreach ($dropshipItem->getData() as $key => $value) {
                        $this->writeValue($key, $value);
                    }
                }
            }
        }

        return $returnArray;
    }
}
